@@ -21,7 +21,8 @@ return 0;
 sub open_last_command
 {
 local ($fh, $user) = @_;
-open($fh, "last $user |");
+local $quser = defined($user) && length($user) ? " ".quotemeta($user) : "";
+open($fh, "last$quser |");
 }
 
 # read_last_line(handle)
@@ -43,14 +44,8 @@ while(1) {
 	}
 }
 
-# encrypt_password(password)
-sub encrypt_password
-{
-# We let the passwd programa to do encryption on Unixware.
-# local $salt = chr(int(rand(26))+65) . chr(int(rand(26))+65);
-# return crypt($_[0], $salt);
-return $_[0];
-}
+# We let the passwd program to do encryption on Unixware.
+$no_encrypt_password = 1;
 
 1;
 
